(*
ocamlsvga - Objective Caml interface for the SVGA library
Copyright (C) 1997 Jean-Christophe FILLIATRE

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Library General Public
License version 2, as published by the Free Software Foundation.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.

See the GNU Library General Public License version 2 for more details
(enclosed in the file LGPL).
*)

(* $Id: vga.mli,v 1.6 1997/05/26 21:58:30 jc Exp $ *)

(* svgalib version : 1.2.10 *)


(* initialization *)

external init : unit -> unit = "vga_init_stub"
	(* raises (Failure "Not a graphics-capable virtual console") if
	   initialization fails *)
external clear : unit -> unit = "vga_clear_stub"


(* SVGA modes *)

type mode
	(* the abstract type of VGA modes *)

val mode_TEXT 	 	: mode
val mode_G320x200x16  	: mode
val mode_G640x200x16  	: mode
val mode_G640x350x16  	: mode
val mode_G640x480x16  	: mode
val mode_G320x200x256 	: mode
val mode_G320x240x256 	: mode
val mode_G320x400x256 	: mode
val mode_G360x480x256 	: mode
val mode_G640x480x2   	: mode

val mode_G640x480x256 	: mode
val mode_G800x600x256 	: mode
val mode_G1024x768x256 	: mode

val mode_G1280x1024x256 : mode	(* Additional modes. *)

val mode_G320x200x32K 	: mode
val mode_G320x200x64K 	: mode
val mode_G320x200x16M 	: mode
val mode_G640x480x32K 	: mode
val mode_G640x480x64K 	: mode
val mode_G640x480x16M 	: mode
val mode_G800x600x32K 	: mode
val mode_G800x600x64K 	: mode
val mode_G800x600x16M 	: mode
val mode_G1024x768x32K 	: mode
val mode_G1024x768x64K 	: mode
val mode_G1024x768x16M 	: mode
val mode_G1280x1024x32K : mode
val mode_G1280x1024x64K : mode
val mode_G1280x1024x16M : mode

val mode_G800x600x16	: mode
val mode_G1024x768x16 	: mode
val mode_G1280x1024x16 	: mode

val mode_G720x348x2 	: mode		(* Hercules emulation mode *)

val mode_G320x200x16M32 : mode		(* 32-bit per pixel modes. *)
val mode_G640x480x16M32 : mode
val mode_G800x600x16M32 : mode
val mode_G1024x768x16M32  : mode
val mode_G1280x1024x16M32 : mode

val mode_G1152x864x16 	: mode		(* additional resolutions *)
val mode_G1152x864x256 	: mode
val mode_G1152x864x32K 	: mode
val mode_G1152x864x64K 	: mode
val mode_G1152x864x16M 	: mode
val mode_G1152x864x16M32 : mode

val mode_G1600x1200x16 	: mode
val mode_G1600x1200x256 : mode
val mode_G1600x1200x32K : mode
val mode_G1600x1200x64K : mode
val mode_G1600x1200x16M : mode
val mode_G1600x1200x16M32 : mode

external lastmodenumber : unit -> mode = "vga_lastmodenumber_stub"

val mode_GLASTMODE	: mode


external getmodename : mode -> string = "vga_getmodename_stub"

val string_of_mode : mode -> string

external getmodenumber : string -> mode = "vga_getmodenumber_stub"
	(* raises (Invalig_argument "getmodenumber") if the argument
	   does not correspond to a mode *)

val mode_of_string : string -> mode
	(* raises (Invalig_argument "mode_of_string") if the argument
	   does not correspond to a mode *)

external hasmode : mode -> bool = "vga_hasmode_stub"

external setmode : mode -> unit = "vga_setmode_stub"

external getdefaultmode : unit -> mode = "vga_getdefaultmode_stub"
	(* raises (Failure "Invalid mode in GSVGAMODE") if the mode
	   specified in the environment variable GSVGAMODE is incorrect *)

external getcurrentmode : unit -> mode = "vga_getcurrentmode_stub"

type chipset

val chipset_UNDEFINED 	: chipset
val chipset_VGA		: chipset
val chipset_ET4000	: chipset
val chipset_CIRRUS	: chipset
val chipset_TVGA8900	: chipset
val chipset_OAK		: chipset
val chipset_EGA		: chipset
val chipset_S3		: chipset
val chipset_ET3000	: chipset
val chipset_MACH32	: chipset
val chipset_GVGA6400	: chipset
val chipset_ARK		: chipset
val chipset_ATI		: chipset
val chipset_ALI		: chipset

val string_of_chipset : chipset -> string

external getcurrentchipset : unit -> chipset = "vga_getcurrentchipset_stub"


external getxdim : unit -> int = "vga_getxdim_stub"

external getydim : unit -> int = "vga_getydim_stub"

external getcolors : unit -> int = "vga_getcolors_stub"

type blit_flag = 
    HAVE_BITBLIT
  | HAVE_FILLBLIT
  | HAVE_IMAGEBLIT
  | HAVE_HLINELISTBLIT
  | HAVE_BLITWAIT
;;

val string_of_blit_flag : blit_flag -> string

type other_flag =
    HAVE_RWPAGE
  | IS_INTERLACED
  | IS_MODEX
  | IS_DYNAMICMODE
  | CAPABLE_LINEAR
  | IS_LINEAR
  | EXT_INFO_AVAILABLE
  | RGB_MISORDERED
  | HAVE_EXT_SET
;;

val string_of_other_flag : other_flag -> string

type modeinfo = {
  width : int ;
  height : int ;
  bytesperpixel : int ;
  colors : int ;
  linewidth : int ;
  maxlogicalwidth : int ;
  startaddressrange : int ;
  maxpixels : int ;
  haveblit : blit_flag list ;
  flags : other_flag list ;
  chiptype : chipset ;
  memory : int ;
  linewidth_unit : int }
;;

external getmodeinfo : mode -> modeinfo = "vga_getmodeinfo_stub"


(* functions to set some of the chipset parameters *)

external setpage : int -> unit = "vga_setpage_stub"
external setreadpage : int -> unit = "vga_setreadpage_stub"
external setwritepage : int -> unit = "vga_setwritepage_stub"
external setlogicalwidth : int -> unit = "vga_setlogicalwidth_stub"
external setdisplaystart : int -> unit = "vga_setdisplaystart_stub"

external claimvideomemory : int -> unit = "vga_claimvideomemory_stub"
       (* may raise [Failure "Not enough memory on the card"] *)

external setmodeX : unit -> unit = "vga_setmodeX_stub"
       (* may raise [Failure "mode X not available"] *)

external disabledriverreport : unit -> unit = "vga_disabledriverreport_stub"

external getmousetype : unit -> int = "vga_getmousetype_stub"
external getmonitortype : unit -> int = "vga_getmonitortype_stub"


(* refresh on/off *)

external screenoff : unit -> unit = "vga_screenoff_stub"

external screenon : unit -> unit = "vga_screenon_stub"

external waitretrace : unit -> unit = "vga_waitretrace_stub"


(* flipping *)

external setflipchar : int -> unit = "vga_setflipchar_stub"

external flip : unit -> unit = "vga_flip_stub"

external getch : unit -> int = "vga_getch_stub"


(* drawing functions *)

external setcolor : int -> unit = "vga_setcolor_stub"

external drawpixel : int -> int -> unit = "vga_drawpixel_stub"

external drawline : int -> int -> int -> int -> unit = "vga_drawline_stub"

external getpixel : int -> int -> int = "vga_getpixel_stub"

external drawscanline : int -> string -> unit = "vga_drawscanline_stub"

external drawscansegment : string -> int -> int -> int -> unit
					      = "vga_drawscansegment_stub"
external getscansegment : string -> int -> int -> int -> unit
					      = "vga_getscansegment_stub"


(* palette *)

external setpalette : int -> int -> int -> int -> unit = "vga_setpalette_stub"

external getpalette : int -> int * int * int = "vga_getpalette_stub"

external setpalvec : int -> int -> int array -> unit = "vga_setpalvec_stub"
	(* [setpalvec start num v] sets the palette entries of colors
	   from [start] to [start+num-1]. [v] is a n array of size at least
	   3*[num]. *)

external getpalvec : int -> int -> int array -> unit = "vga_getpalvec_stub"

external white : unit -> int = "vga_white_stub"

external setegacolor : int -> unit = "vga_setegacolor_stub"

external setrgbcolor : int -> int -> int -> unit = "vga_setrgbcolor_stub"


(* keyboard *)

val getkey : unit -> int


(* dump the VGA registers *)

external dumpregs : unit -> unit = "vga_dumpregs_stub"
